@@ -13,6 +13,7 @@ using Microsoft.DotNet.Build.Tasks.Feed.Model;
 using Microsoft.DotNet.Build.Tasks.Feed.Tests.TestDoubles;
 using Xunit;
 using static Microsoft.DotNet.Build.Tasks.Feed.GeneralUtils;
+using static Microsoft.DotNet.Build.CloudTestTasks.AzureStorageUtils;
 
 namespace Microsoft.DotNet.Build.Tasks.Feed.Tests
 {
@@ -123,7 +124,7 @@ namespace Microsoft.DotNet.Build.Tasks.Feed.Tests
 
             var httpClient = FakeHttpClient.WithResponses(response);
 
-            var result = await GeneralUtils.CompareLocalPackageToFeedPackage(
+            var result = await CompareLocalPackageToFeedPackage(
                 localPackagePath,
                 packageContentUrl,
                 httpClient,
@@ -164,7 +165,7 @@ namespace Microsoft.DotNet.Build.Tasks.Feed.Tests
 
             var httpClient = FakeHttpClient.WithResponses(responses);
 
-            await GeneralUtils.CompareLocalPackageToFeedPackage(
+            await CompareLocalPackageToFeedPackage(
                 localPackagePath,
                 packageContentUrl,
                 httpClient,
