@@ -81,6 +81,12 @@ namespace Microsoft.DotNet.Build.Tasks.Feed
         /// </summary>
         public string RepoCommit { get; set; }
 
+        /// <summary>
+        /// Indicates the source of the artifacts. For a VMR build, the repository name is dotnet/dotnet,
+        /// while the repository origin name corresponds to the actual product repository.
+        /// </summary>
+        public string RepoOrigin { get; set; }
+
         /// <summary>
         /// Is this manifest for a stable build?
         /// </summary>
@@ -136,6 +142,7 @@ namespace Microsoft.DotNet.Build.Tasks.Feed
                     RepoUri,
                     RepoBranch,
                     RepoCommit,
+                    RepoOrigin,
                     IsStableBuild,
                     targetPublishingVersion,
                     IsReleaseOnlyPackageVersion);
