@@ -54,7 +54,7 @@ namespace Microsoft.DotNet.Build.Tasks.Feed
         /// Metadata LatestLinkShortUrlPrefixes (optional): If provided, AKA ms links are generated (for artifacts blobs only)
         ///                                               that target this short url path. The link is construct as such:
         ///                                               aka.ms/AkaShortUrlPath/BlobArtifactPath -> Target blob url
-        ///                                               If specified, then AkaMSClientId, AkaMSClientSecret and AkaMSTenant must be provided.
+        ///                                               If specified, then AkaMSClientId, AkaMSClientCertificate and AkaMSTenant must be provided.
         ///                                               The version information is stripped away from the file and blob artifact path.
         /// </summary>
         public ITaskItem[] TargetFeedConfig { get; set; }
@@ -167,8 +167,6 @@ namespace Microsoft.DotNet.Build.Tasks.Feed
 
         public string AkaMSClientId { get; set; }
 
-        public string AkaMSClientSecret { get; set; }
-
         /// <summary>
         /// Path to client certificate
         /// </summary>
@@ -281,7 +279,6 @@ namespace Microsoft.DotNet.Build.Tasks.Feed
                         IMaestroApi client = MaestroApiFactory.GetAuthenticated(
                             MaestroApiEndpoint,
                             BuildAssetRegistryToken,
-                            MaestroApiFederatedToken,
                             MaestroManagedIdentityId,
                             !AllowInteractiveAuthentication);
                         Maestro.Client.Models.Build buildInformation = await client.Builds.GetBuildAsync(BARBuildId);
@@ -353,9 +350,10 @@ namespace Microsoft.DotNet.Build.Tasks.Feed
                 InternalBuild = this.InternalBuild,
                 SkipSafetyChecks = this.SkipSafetyChecks,
                 AkaMSClientId = this.AkaMSClientId,
-                AkaMSClientSecret = this.AkaMSClientSecret,
                 AkaMSClientCertificate = !string.IsNullOrEmpty(AkaMSClientCertificate) ?
+#pragma warning disable SYSLIB0057 // https://github.com/dotnet/arcade/issues/14936
                     new X509Certificate2(Convert.FromBase64String(File.ReadAllText(AkaMSClientCertificate))) : null,
+#pragma warning restore
                 AkaMSCreatedBy = this.AkaMSCreatedBy,
                 AkaMSGroupOwner = this.AkaMSGroupOwner,
                 AkaMsOwners = this.AkaMsOwners,
