@@ -134,8 +134,6 @@ namespace Microsoft.DotNet.Build.Tasks.Feed
 
         public string AkaMSClientId { get; set; }
 
-        public string AkaMSClientSecret { get; set; }
-
         public X509Certificate2 AkaMSClientCertificate { get; set; }
 
         public string AkaMSTenant { get; set; }
@@ -1517,17 +1515,6 @@ namespace Microsoft.DotNet.Build.Tasks.Feed
                             AkaMsOwners,
                             Log);
                     }
-                    else if (!string.IsNullOrEmpty(AkaMSClientSecret))
-                    {
-                        LinkManager = new LatestLinksManager(
-                            AkaMSClientId,
-                            AkaMSClientSecret,
-                            AkaMSTenant,
-                            AkaMSGroupOwner,
-                            AkaMSCreatedBy,
-                            AkaMsOwners,
-                            Log);
-                    }
                     else
                     {
                         throw new InvalidOperationException("Cannot create latest links for feed config without aka.ms authentication information");
