@@ -2,6 +2,7 @@
 // The .NET Foundation licenses this file to you under the MIT license.
 
 using System.Threading.Tasks;
+using Azure.Identity;
 using Microsoft.DotNet.Build.CloudTestTasks;
 
 namespace Microsoft.DotNet.Build.Tasks.Feed
@@ -14,13 +15,15 @@ namespace Microsoft.DotNet.Build.Tasks.Feed
         /// </summary>
         public bool FailIfExists { get; set; }
 
-        public override async Task<AzureStorageUtils> GetBlobStorageUtilsAsync(string accountName, string accountKey, string containerName)
+        public override async Task<AzureStorageUtils> GetBlobStorageUtilsAsync()
         {
-            AzureStorageUtils blobUtils = new(accountName, accountKey, containerName);
+            var blobUtils = AccountKey is null ?
+                new AzureStorageUtils(AccountName, new AzureCliCredential(), ContainerName) :
+                new AzureStorageUtils(AccountName, AccountKey, ContainerName);
 
             if (FailIfExists && await blobUtils.CheckIfContainerExistsAsync())
             {
-                throw new System.InvalidOperationException($"Container {containerName} already exists in storage account {accountName}.");
+                throw new System.InvalidOperationException($"Container {ContainerName} already exists in storage account {AccountName}.");
             }
 
             return blobUtils;
