@@ -110,13 +110,6 @@ namespace Microsoft.DotNet.Build.Tasks.Feed.Model
         private const string FeedDotNet10Transport = "https://pkgs.dev.azure.com/dnceng/public/_packaging/dotnet10-transport/nuget/v3/index.json";
         private const string FeedDotNet10Workloads = "https://pkgs.dev.azure.com/dnceng/public/_packaging/dotnet10-workloads/nuget/v3/index.json";
 
-        private const string FeedDotNet10InternalShipping = "https://pkgs.dev.azure.com/dnceng/internal/_packaging/dotnet10-internal/nuget/v3/index.json";
-        private const string FeedDotNet10InternalTransport = "https://pkgs.dev.azure.com/dnceng/internal/_packaging/dotnet10-internal-transport/nuget/v3/index.json";
-
-        private const string FeedDotNet11Shipping = "https://pkgs.dev.azure.com/dnceng/public/_packaging/dotnet11/nuget/v3/index.json";
-        private const string FeedDotNet11Transport = "https://pkgs.dev.azure.com/dnceng/public/_packaging/dotnet11-transport/nuget/v3/index.json";
-        private const string FeedDotNet11Workloads = "https://pkgs.dev.azure.com/dnceng/public/_packaging/dotnet11-workloads/nuget/v3/index.json";
-
         private const string FeedDotNetLibrariesShipping = "https://pkgs.dev.azure.com/dnceng/public/_packaging/dotnet-libraries/nuget/v3/index.json";
         private const string FeedDotNetLibrariesTransport = "https://pkgs.dev.azure.com/dnceng/public/_packaging/dotnet-libraries-transport/nuget/v3/index.json";
 
@@ -220,14 +213,6 @@ namespace Microsoft.DotNet.Build.Tasks.Feed.Model
             (TargetFeedContentType.Checksum, FeedStagingForChecksums),
         };
 
-        private static TargetFeedSpecification[] DotNet10InternalFeeds =
-        {
-            (TargetFeedContentType.Package, FeedDotNet10InternalShipping, AssetSelection.ShippingOnly),
-            (TargetFeedContentType.Package, FeedDotNet10InternalTransport, AssetSelection.NonShippingOnly),
-            (InstallersAndSymbols, FeedStagingInternalForInstallers),
-            (TargetFeedContentType.Checksum, FeedStagingInternalForChecksums),
-        };
-
         private static TargetFeedSpecification[] DotNet10WorkloadFeeds =
         {
             (TargetFeedContentType.Package, FeedDotNet10Workloads, AssetSelection.ShippingOnly),
@@ -235,30 +220,6 @@ namespace Microsoft.DotNet.Build.Tasks.Feed.Model
             (InstallersAndSymbols, FeedStagingForInstallers),
             (TargetFeedContentType.Checksum, FeedStagingForChecksums),
         };
-        
-        private static TargetFeedSpecification[] DotNet11Feeds =
-        {
-            (TargetFeedContentType.Package, FeedDotNet11Shipping, AssetSelection.ShippingOnly),
-            (TargetFeedContentType.Package, FeedDotNet11Transport, AssetSelection.NonShippingOnly),
-            (TargetFeedContentType.Package, FeedDotNetEng, AssetSelection.ShippingOnly),
-            (TargetFeedContentType.Package, FeedDotNetEng, AssetSelection.NonShippingOnly),
-            (TargetFeedContentType.Package, FeedDotNet11Shipping, AssetSelection.ShippingOnly),
-            (TargetFeedContentType.Package, FeedDotNet11Transport, AssetSelection.NonShippingOnly),
-            (TargetFeedContentType.Package, FeedDotNetLibrariesShipping, AssetSelection.ShippingOnly),
-            (TargetFeedContentType.Package, FeedDotNetLibrariesTransport, AssetSelection.NonShippingOnly),
-            (TargetFeedContentType.Package, FeedDotNetTools, AssetSelection.ShippingOnly),
-            (TargetFeedContentType.Package, FeedDotNetTools, AssetSelection.NonShippingOnly),
-            (InstallersAndSymbols, FeedStagingForInstallers),
-            (TargetFeedContentType.Checksum, FeedStagingForChecksums),
-        };
-        
-        private static TargetFeedSpecification[] DotNet11WorkloadFeeds =
-        {
-            (TargetFeedContentType.Package, FeedDotNet11Workloads, AssetSelection.ShippingOnly),
-            (TargetFeedContentType.Package, FeedDotNet11Workloads, AssetSelection.NonShippingOnly),
-            (InstallersAndSymbols, FeedStagingForInstallers),
-            (TargetFeedContentType.Checksum, FeedStagingForChecksums),
-        };
 
         private static TargetFeedSpecification[] DotNetEngFeeds =
         {
@@ -487,6 +448,136 @@ namespace Microsoft.DotNet.Build.Tasks.Feed.Model
                 symbolTargetType: InternalSymbolTargets,
                 filenamesToExclude: FilenamesToExclude),
 
+            // .NET 7,
+            new TargetChannelConfig(
+                id: 2236,
+                isInternal: false,
+                publishingInfraVersion: PublishingInfraVersion.Latest,
+                akaMSChannelNames: new List<string>() { "7.0" },
+                targetFeeds: DotNet7Feeds,
+                symbolTargetType: PublicAndInternalSymbolTargets,
+                filenamesToExclude: FilenamesToExclude),
+
+            // .NET 7 Eng,
+            new TargetChannelConfig(
+                id: 3114,
+                isInternal: false,
+                publishingInfraVersion: PublishingInfraVersion.Latest,
+                akaMSChannelNames: new List<string>() { "eng/net7" },
+                targetFeeds: DotNetEngFeeds,
+                symbolTargetType: PublicAndInternalSymbolTargets,
+                filenamesToExclude: FilenamesToExclude),
+
+            // .NET 7 Eng - Validation,
+            new TargetChannelConfig(
+                id: 3115,
+                isInternal: false,
+                publishingInfraVersion: PublishingInfraVersion.Latest,
+                akaMSChannelNames: new List<string>() { "eng/net7validation" },
+                targetFeeds: DotNetEngFeeds,
+                symbolTargetType: PublicAndInternalSymbolTargets,
+                flatten: false),
+
+            // .NET 7 Internal,
+            new TargetChannelConfig(
+                id: 3035,
+                isInternal: true,
+                publishingInfraVersion: PublishingInfraVersion.Latest,
+                akaMSChannelNames: new List<string>() { "internal/7.0" },
+                targetFeeds: DotNet7InternalFeeds,
+                symbolTargetType: InternalSymbolTargets,
+                filenamesToExclude: FilenamesToExclude),
+
+            // .NET 7 Private,
+            new TargetChannelConfig(
+                id: 4099,
+                isInternal: true,
+                publishingInfraVersion: PublishingInfraVersion.Latest,
+                akaMSChannelNames: new List<string>() { "internal/7.0-private" },
+                targetFeeds: DotNet7InternalFeeds,
+                symbolTargetType: InternalSymbolTargets,
+                filenamesToExclude: FilenamesToExclude),
+
+            // .NET 7.0.1xx SDK,
+            new TargetChannelConfig(
+                id: 2237,
+                isInternal: false,
+                publishingInfraVersion: PublishingInfraVersion.Latest,
+                akaMSChannelNames: new List<string>() { "7.0.1xx", "7.0" },
+                targetFeeds: DotNet7Feeds,
+                symbolTargetType: PublicAndInternalSymbolTargets,
+                filenamesToExclude: FilenamesToExclude),
+
+            // .NET 7.0.1xx SDK Internal,
+            new TargetChannelConfig(
+                id: 3038,
+                isInternal: true,
+                publishingInfraVersion: PublishingInfraVersion.Latest,
+                akaMSChannelNames: new List<string>() { "internal/7.0.1xx", "internal/7.0" },
+                targetFeeds: DotNet7InternalFeeds,
+                symbolTargetType: InternalSymbolTargets,
+                filenamesToExclude: FilenamesToExclude),
+
+            // .NET 7.0.2xx SDK,
+            new TargetChannelConfig(
+                id: 3259,
+                isInternal: false,
+                publishingInfraVersion: PublishingInfraVersion.Latest,
+                akaMSChannelNames: new List<string>() { "7.0.2xx" },
+                targetFeeds: DotNet7Feeds,
+                symbolTargetType: PublicAndInternalSymbolTargets,
+                filenamesToExclude: FilenamesToExclude),
+
+            // .NET 7.0.2xx SDK Internal,
+            new TargetChannelConfig(
+                id: 3260,
+                isInternal: true,
+                publishingInfraVersion: PublishingInfraVersion.Latest,
+                akaMSChannelNames: new List<string>() { "internal/7.0.2xx" },
+                targetFeeds: DotNet7InternalFeeds,
+                symbolTargetType: InternalSymbolTargets,
+                filenamesToExclude: FilenamesToExclude),
+
+            // .NET 7.0.3xx SDK,
+            new TargetChannelConfig(
+                id: 3436,
+                isInternal: false,
+                publishingInfraVersion: PublishingInfraVersion.Latest,
+                akaMSChannelNames: new List<string>() { "7.0.3xx" },
+                targetFeeds: DotNet7Feeds,
+                symbolTargetType: PublicAndInternalSymbolTargets,
+                filenamesToExclude: FilenamesToExclude),
+
+            // .NET 7.0.3xx SDK Internal,
+            new TargetChannelConfig(
+                id: 3435,
+                isInternal: true,
+                publishingInfraVersion: PublishingInfraVersion.Latest,
+                akaMSChannelNames: new List<string>() { "internal/7.0.3xx" },
+                targetFeeds: DotNet7InternalFeeds,
+                symbolTargetType: InternalSymbolTargets,
+                filenamesToExclude: FilenamesToExclude),
+
+            // .NET 7.0.4xx SDK,
+            new TargetChannelConfig(
+                id: 3600,
+                isInternal: false,
+                publishingInfraVersion: PublishingInfraVersion.Latest,
+                akaMSChannelNames: new List<string>() { "7.0.4xx" },
+                targetFeeds: DotNet7Feeds,
+                symbolTargetType: PublicAndInternalSymbolTargets,
+                filenamesToExclude: FilenamesToExclude),
+
+            // .NET 7.0.4xx SDK Internal,
+            new TargetChannelConfig(
+                id: 3601,
+                isInternal: true,
+                publishingInfraVersion: PublishingInfraVersion.Latest,
+                akaMSChannelNames: new List<string>() { "internal/7.0.4xx" },
+                targetFeeds: DotNet7InternalFeeds,
+                symbolTargetType: InternalSymbolTargets,
+                filenamesToExclude: FilenamesToExclude),
+
             // .NET 8,
             new TargetChannelConfig(
                 id: 3073,
@@ -707,42 +798,82 @@ namespace Microsoft.DotNet.Build.Tasks.Feed.Model
                 symbolTargetType: InternalSymbolTargets,
                 filenamesToExclude: FilenamesToExclude),
 
-            // .NET 9.0.2xx SDK,
+            // .NET 9 RC 1
             new TargetChannelConfig(
-                id: 5286,
+                id: 5119,
                 isInternal: false,
                 publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: new List<string>() { "9.0.2xx" },
+                akaMSChannelNames: new List<string>() { "9.0-rc1" },
                 targetFeeds: DotNet9Feeds,
                 symbolTargetType: PublicAndInternalSymbolTargets,
                 filenamesToExclude: FilenamesToExclude),
 
-            // .NET 9.0.2xx SDK Internal,
+            // .NET 9 RC 1 Internal
             new TargetChannelConfig(
-                id: 5287,
+                id: 5120,
                 isInternal: true,
                 publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: new List<string>() { "internal/9.0.2xx" },
+                akaMSChannelNames: new List<string>() { "internal/9.0-rc1" },
                 targetFeeds: DotNet9InternalFeeds,
                 symbolTargetType: InternalSymbolTargets,
                 filenamesToExclude: FilenamesToExclude),
 
-            // .NET 9.0.3xx SDK,
+            // .NET 9 RC 2
             new TargetChannelConfig(
-                id: 6417,
+                id: 5122,
                 isInternal: false,
                 publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["9.0.3xx"],
+                akaMSChannelNames: new List<string>() { "9.0-rc2" },
                 targetFeeds: DotNet9Feeds,
                 symbolTargetType: PublicAndInternalSymbolTargets,
                 filenamesToExclude: FilenamesToExclude),
 
-            // .NET 9.0.3xx SDK Internal,
+            // .NET 9 RC 2 Internal
             new TargetChannelConfig(
-                id: 6418,
+                id: 5121,
                 isInternal: true,
                 publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["internal/9.0.3xx"],
+                akaMSChannelNames: new List<string>() { "internal/9.0-rc2" },
+                targetFeeds: DotNet9InternalFeeds,
+                symbolTargetType: InternalSymbolTargets,
+                filenamesToExclude: FilenamesToExclude),
+
+            // .NET 9.0.1xx SDK RC 1
+            new TargetChannelConfig(
+                id: 5123,
+                isInternal: false,
+                publishingInfraVersion: PublishingInfraVersion.Latest,
+                akaMSChannelNames: new List<string>() { "9.0-rc1", "9.0.1xx-rc1" },
+                targetFeeds: DotNet9Feeds,
+                symbolTargetType: PublicAndInternalSymbolTargets,
+                filenamesToExclude: FilenamesToExclude),
+
+            // .NET 9.0.1xx SDK RC 1 Internal
+            new TargetChannelConfig(
+                id: 5126,
+                isInternal: true,
+                publishingInfraVersion: PublishingInfraVersion.Latest,
+                akaMSChannelNames: new List<string>() { "internal/9.0-rc1", "internal/9.0.1xx-rc1" },
+                targetFeeds: DotNet9InternalFeeds,
+                symbolTargetType: InternalSymbolTargets,
+                filenamesToExclude: FilenamesToExclude),
+
+            // .NET 9.0.1xx SDK RC 2
+            new TargetChannelConfig(
+                id: 5124,
+                isInternal: false,
+                publishingInfraVersion: PublishingInfraVersion.Latest,
+                akaMSChannelNames: new List<string>() { "9.0-rc2", "9.0.1xx-rc2" },
+                targetFeeds: DotNet9Feeds,
+                symbolTargetType: PublicAndInternalSymbolTargets,
+                filenamesToExclude: FilenamesToExclude),
+
+            // .NET 9.0.1xx SDK RC 2 Internal
+            new TargetChannelConfig(
+                id: 5125,
+                isInternal: true,
+                publishingInfraVersion: PublishingInfraVersion.Latest,
+                akaMSChannelNames: new List<string>() { "internal/9.0-rc2", "internal/9.0.1xx-rc2" },
                 targetFeeds: DotNet9InternalFeeds,
                 symbolTargetType: InternalSymbolTargets,
                 filenamesToExclude: FilenamesToExclude),
@@ -757,26 +888,6 @@ namespace Microsoft.DotNet.Build.Tasks.Feed.Model
                 symbolTargetType: PublicAndInternalSymbolTargets,
                 filenamesToExclude: FilenamesToExclude),
 
-            // .NET 10 Eng,
-            new TargetChannelConfig(
-                id: 8394,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: new List<string>() { "eng/net10" },
-                targetFeeds: DotNetEngFeeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10 Eng - Validation,
-            new TargetChannelConfig(
-                id: 8395,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: new List<string>() { "eng/net10validation" },
-                targetFeeds: DotNetEngFeeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                flatten: false),
-
             // .NET 10 Workload Release,
             new TargetChannelConfig(
                 id: 5174,
@@ -797,253 +908,6 @@ namespace Microsoft.DotNet.Build.Tasks.Feed.Model
                 symbolTargetType: PublicAndInternalSymbolTargets,
                 filenamesToExclude: FilenamesToExclude),
 
-            // .NET 10 Preview 1,
-            new TargetChannelConfig(
-                id: 6545,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["10.0-preview1"],
-                targetFeeds: DotNet10Feeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10 Preview 2,
-            new TargetChannelConfig(
-                id: 6547,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["10.0-preview2"],
-                targetFeeds: DotNet10Feeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10 Preview 3,
-            new TargetChannelConfig(
-                id: 6549,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["10.0-preview3"],
-                targetFeeds: DotNet10Feeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10 Preview 4,
-            new TargetChannelConfig(
-                id: 6551,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["10.0-preview4"],
-                targetFeeds: DotNet10Feeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10 Preview 5,
-            new TargetChannelConfig(
-                id: 6553,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["10.0-preview5"],
-                targetFeeds: DotNet10Feeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10 Preview 6,
-            new TargetChannelConfig(
-                id: 6555,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["10.0-preview6"],
-                targetFeeds: DotNet10Feeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10 Preview 7,
-            new TargetChannelConfig(
-                id: 6557,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["10.0-preview7"],
-                targetFeeds: DotNet10Feeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10 RC 1,
-            new TargetChannelConfig(
-                id: 6494,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["10.0-rc1"],
-                targetFeeds: DotNet10Feeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10 RC 1 Internal,
-            new TargetChannelConfig(
-                id: 6496,
-                isInternal: true,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["internal/10.0-rc1"],
-                targetFeeds: DotNet10InternalFeeds,
-                symbolTargetType: InternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10 RC 2,
-            new TargetChannelConfig(
-                id: 6498,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["10.0-rc2"],
-                targetFeeds: DotNet10Feeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10 RC 2 Internal,
-            new TargetChannelConfig(
-                id: 6500,
-                isInternal: true,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["internal/10.0-rc2"],
-                targetFeeds: DotNet10InternalFeeds,
-                symbolTargetType: InternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10.0.1xx RC 1,
-            new TargetChannelConfig(
-                id: 6573,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["10.0.1xx-rc1"],
-                targetFeeds: DotNet10Feeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10.0.1xx RC 1 Internal,
-            new TargetChannelConfig(
-                id: 6575,
-                isInternal: true,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["internal/10.0.1xx-rc1"],
-                targetFeeds: DotNet10Feeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10.0.1xx RC 2,
-            new TargetChannelConfig(
-                id: 6577,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["10.0.1xx-rc2"],
-                targetFeeds: DotNet10Feeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10.0.1xx RC 2 Internal,
-            new TargetChannelConfig(
-                id: 6579,
-                isInternal: true,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["internal/10.0.1xx-rc2"],
-                targetFeeds: DotNet10InternalFeeds,
-                symbolTargetType: InternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10.0.1xx SDK Preview 1,
-            new TargetChannelConfig(
-                id: 6476,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["10.0.1xx-preview1"],
-                targetFeeds: DotNet10Feeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10.0.1xx SDK Preview 2,
-            new TargetChannelConfig(
-                id: 6478,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["10.0.1xx-preview2"],
-                targetFeeds: DotNet10Feeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10.0.1xx SDK Preview 3,
-            new TargetChannelConfig(
-                id: 6484,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["10.0.1xx-preview3"],
-                targetFeeds: DotNet10Feeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10.0.1xx SDK Preview 4,
-            new TargetChannelConfig(
-                id: 6486,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["10.0.1xx-preview4"],
-                targetFeeds: DotNet10Feeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10.0.1xx SDK Preview 5,
-            new TargetChannelConfig(
-                id: 6488,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["10.0.1xx-preview5"],
-                targetFeeds: DotNet10Feeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10.0.1xx SDK Preview 6,
-            new TargetChannelConfig(
-                id: 6490,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["10.0.1xx-preview6"],
-                targetFeeds: DotNet10Feeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 10.0.1xx SDK Preview 7,
-            new TargetChannelConfig(
-                id: 6492,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["10.0.1xx-preview7"],
-                targetFeeds: DotNet10Feeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude),
-
-            // .NET 11,
-            new TargetChannelConfig(
-                id: 8297,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: ["11.0"],
-                targetFeeds: DotNet11Feeds,
-                symbolTargetType: PublicAndInternalSymbolTargets),
-
-            // .NET 11 Workload Release,
-            new TargetChannelConfig(
-                id: 8299,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: [ "11.0-workloads" ],
-                targetFeeds: DotNet11WorkloadFeeds,
-                symbolTargetType: PublicAndInternalSymbolTargets),
-
-            // .NET 11.0.1xx SDK,
-            new TargetChannelConfig(
-                id: 8298,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: [ "11.0.1xx", "11.0" ],
-                targetFeeds: DotNet11Feeds,
-                symbolTargetType: PublicAndInternalSymbolTargets),
-
             // .NET Core Experimental,
             new TargetChannelConfig(
                 id: 562,
@@ -1395,7 +1259,7 @@ namespace Microsoft.DotNet.Build.Tasks.Feed.Model
                 symbolTargetType: PublicAndInternalSymbolTargets,
                 filenamesToExclude: FilenamesToExclude,
                 flatten: false),
-                // VS 17.12
+            // VS 17.12
             new TargetChannelConfig(
                 id: 4906,
                 isInternal: false,
@@ -1405,104 +1269,7 @@ namespace Microsoft.DotNet.Build.Tasks.Feed.Model
                 symbolTargetType: PublicAndInternalSymbolTargets,
                 filenamesToExclude: FilenamesToExclude,
                 flatten: false),
-            // VS 17.13
-            new TargetChannelConfig(
-                id: 5288,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: new List<string>(),
-                targetFeeds: DotNetToolsFeeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude,
-                flatten: false),
-            // VS 17.14
-            new TargetChannelConfig(
-                id: 6136,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: new List<string>(),
-                targetFeeds: DotNetToolsFeeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude,
-                flatten: false),
-            
-            // 18.0
-            new TargetChannelConfig(
-                id: 7987,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: new List<string>(),
-                targetFeeds: DotNetToolsFeeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude,
-                flatten: false),
-            
-            // 18.1
-            new TargetChannelConfig(
-                id: 8703,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: new List<string>(),
-                targetFeeds: DotNetToolsFeeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude,
-                flatten: false),
-            
-            // 18.2
-            new TargetChannelConfig(
-                id: 8704,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: new List<string>(),
-                targetFeeds: DotNetToolsFeeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude,
-                flatten: false),
-            
-            // 18.3
-            new TargetChannelConfig(
-                id: 8705,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: new List<string>(),
-                targetFeeds: DotNetToolsFeeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude,
-                flatten: false),
-            
-            // 18.4
-            new TargetChannelConfig(
-                id: 8706,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: new List<string>(),
-                targetFeeds: DotNetToolsFeeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude,
-                flatten: false),
-
-            // 18.5
-            new TargetChannelConfig(
-                id: 8707,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: new List<string>(),
-                targetFeeds: DotNetToolsFeeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude,
-                flatten: false),
-            
-            // 18.6
-            new TargetChannelConfig(
-                id: 8708,
-                isInternal: false,
-                publishingInfraVersion: PublishingInfraVersion.Latest,
-                akaMSChannelNames: new List<string>(),
-                targetFeeds: DotNetToolsFeeds,
-                symbolTargetType: PublicAndInternalSymbolTargets,
-                filenamesToExclude: FilenamesToExclude,
-                flatten: false),
-            };
+        };
         #endregion
     }
 }
