@@ -1,7 +1,7 @@
 // Licensed to the .NET Foundation under one or more agreements.
 // The .NET Foundation licenses this file to you under the MIT license.
 
-namespace Microsoft.DotNet.Deployment.Tasks.Links.src
+namespace Microsoft.DotNet.Deployment.Tasks.Links
 {
     /// <summary>
     ///     A single aka.ms link.
